@@ -128,11 +128,8 @@ def post_install():
     print("")
     print("Starting config.")
 
-    from os import getcwd
-    print("CWD: " + getcwd())
-
-    from pbclient.tools.pb_config import start_config
-    start_config()
+    from pbclient.prefs import Prefs
+    Prefs().load_from_console()
 
     print("Installing crontab job.")
     _crontab_config.install()
